@@ -44,14 +44,16 @@ class HighEntropyStringsPlugin(BasePlugin, metaclass=ABCMeta):
             yield result
 
     def analyze_line(
-        self,
-        filename: str,
-        line: str,
-        line_number: int = 0,
-        context: CodeSnippet | None = None,
-        raw_context: CodeSnippet | None = None,
-        enable_eager_search: bool = False,
-        **kwargs: Any,
+            self,
+            filename: str,
+            line: str,
+            line_number: int = 0,
+            context: CodeSnippet | None = None,
+            raw_context: CodeSnippet | None = None,
+            is_added: bool = False,
+            is_removed: bool = False,
+            enable_eager_search: bool = False,
+            **kwargs: Any,
     ) -> Set[PotentialSecret]:
         output = super().analyze_line(
             filename=filename,
@@ -59,6 +61,8 @@ class HighEntropyStringsPlugin(BasePlugin, metaclass=ABCMeta):
             line_number=line_number,
             context=context,
             raw_context=raw_context,
+            is_added=is_added,
+            is_removed=is_removed,
         )
         if output or not enable_eager_search:
             # NOTE: We perform the limit filter at this layer (rather than analyze_string) so
