@@ -57,6 +57,8 @@ DENYLIST = (
     'key_?pass',
     'password',
     'passwd',
+    'token',
+    '_pass\\b',
     'pwd',
     'secret',
     'contraseña',
@@ -312,6 +314,8 @@ class KeywordDetector(BasePlugin):
         line_number: int = 0,
         context: CodeSnippet | None = None,
         raw_context: CodeSnippet | None = None,
+        is_added: bool = False,
+        is_removed: bool = False,
         **kwargs: Any,
     ) -> Set[PotentialSecret]:
         filetype = determine_file_type(filename)
@@ -322,6 +326,8 @@ class KeywordDetector(BasePlugin):
             line_number=line_number,
             context=context,
             raw_context=raw_context,
+            is_added=is_added,
+            is_removed=is_removed,
             denylist_regex_to_group=denylist_regex_to_group,
         )
 
